@@ -26,7 +26,7 @@ def load_vocab(dict_path, encoding='utf-8', simplified=False, startwith=None):
             if t not in new_token_dict:
                 keep = True
                 if len(t) > 1:
-                    for c in (t[2:] if t[:2] == '##' else t):
+                    for c in Tokenizer.stem(t):
                         if (
                             Tokenizer._is_cjk_character(c) or
                             Tokenizer._is_punctuation(c)
@@ -45,9 +45,7 @@ def load_vocab(dict_path, encoding='utf-8', simplified=False, startwith=None):
 class BasicTokenizer(object):
     """分词器基类
     """
-    def __init__(
-        self, token_start='[CLS]', token_end='[SEP]', do_lower_case=False
-    ):
+    def __init__(self, token_start='[CLS]', token_end='[SEP]'):
         """初始化
         """
         self._token_pad = '[PAD]'
@@ -55,20 +53,10 @@ class BasicTokenizer(object):
         self._token_mask = '[MASK]'
         self._token_start = token_start
         self._token_end = token_end
-        self._do_lower_case = do_lower_case
 
     def tokenize(self, text, max_length=None):
         """分词函数
         """
-        if self._do_lower_case:
-            if is_py2:
-                text = unicode(text)
-            text = unicodedata.normalize('NFD', text)
-            text = ''.join([
-                ch for ch in text if unicodedata.category(ch) != 'Mn'
-            ])
-            text = text.lower()
-
         tokens = self._tokenize(text)
         if self._token_start is not None:
             tokens.insert(0, self._token_start)
@@ -76,7 +64,8 @@ class BasicTokenizer(object):
             tokens.append(self._token_end)
 
         if max_length is not None:
-            self.truncate_sequence(max_length, tokens, None, -2)
+            index = int(self._token_end is not None) + 1
+            self.truncate_sequence(max_length, tokens, None, -index)
 
         return tokens
 
@@ -180,13 +169,14 @@ class Tokenizer(BasicTokenizer):
     """Bert原生分词器
     纯Python实现，代码修改自keras_bert的tokenizer实现
     """
-    def __init__(self, token_dict, *args, **kwargs):
+    def __init__(self, token_dict, do_lower_case=False, *args, **kwargs):
         """初始化
         """
         super(Tokenizer, self).__init__(*args, **kwargs)
         if is_string(token_dict):
             token_dict = load_vocab(token_dict)
 
+        self._do_lower_case = do_lower_case
         self._token_dict = token_dict
         self._token_dict_inv = {v: k for k, v in token_dict.items()}
         self._vocab_size = len(token_dict)
@@ -242,6 +232,15 @@ class Tokenizer(BasicTokenizer):
     def _tokenize(self, text):
         """基本分词函数
         """
+        if self._do_lower_case:
+            if is_py2:
+                text = unicode(text)
+            text = unicodedata.normalize('NFD', text)
+            text = ''.join([
+                ch for ch in text if unicodedata.category(ch) != 'Mn'
+            ])
+            text = text.lower()
+
         spaced = ''
         for ch in text:
             if self._is_punctuation(ch) or self._is_cjk_character(ch):
@@ -283,6 +282,15 @@ class Tokenizer(BasicTokenizer):
 
         return tokens
 
+    @staticmethod
+    def stem(token):
+        """获取token的“词干”（如果是##开头，则自动去掉##）
+        """
+        if token[:2] == '##':
+            return token[2:]
+        else:
+            return token
+
     @staticmethod
     def _is_space(ch):
         """空格类字符判断
@@ -335,6 +343,38 @@ class Tokenizer(BasicTokenizer):
         """
         return bool(ch) and (ch[0] == '[') and (ch[-1] == ']')
 
+    def rematch(self, text, tokens):
+        """给出原始的text和tokenize后的tokens的映射关系
+        """
+        if is_py2:
+            text = unicode(text)
+
+        normalized_text, char_mapping = '', []
+        for i, ch in enumerate(text):
+            if self._do_lower_case:
+                ch = unicodedata.normalize('NFD', ch)
+                ch = ''.join([c for c in ch if unicodedata.category(c) != 'Mn'])
+            ch = ''.join([
+                c for c in ch
+                if not (ord(c) == 0 or ord(c) == 0xfffd or self._is_control(c))
+            ])
+            normalized_text += ch
+            char_mapping.extend([i] * len(ch))
+        text = normalized_text.lower()
+
+        token_mapping, offset = [], 0
+        for token in tokens:
+            if self._is_special(token):
+                token_mapping.append([])
+            else:
+                token = self.stem(token)
+                start = text[offset:].index(token) + offset
+                end = start + len(token)
+                token_mapping.append(char_mapping[start:end])
+                offset = end
+
+        return token_mapping
+
 
 class SpTokenizer(BasicTokenizer):
     """基于SentencePiece模型的封装，使用上跟Tokenizer基本一致。
